==> ejc-procurement-impl-3.0.0-20251215.092522-124-sources.jar: com/ejianc/business/procurement/perform/bean/ReviewAnnounceConfirmEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购前公示结果评审-审查清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_review_announce_confirm")
public class ReviewAnnounceConfirmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="name")
    private String name; // 审查内容及标准
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="tid")
    private String tid;
    @TableField(value="tpid")
    private String tpid;


    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    
}

==> ejc-procurement-impl-3.0.0-20251216.083149-135-sources.jar: com/ejianc/business/procurement/perform/bean/ReviewAnnounceConfirmEntity.java <==
package com.ejianc.business.procurement.perform.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 采购前公示结果评审-审查清单
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procurement_review_announce_confirm")
public class ReviewAnnounceConfirmEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="pid")
    private Long pid; // 主表主键
    @TableField(value="sequence")
    private Integer sequence; // 排序
    @TableField(value="name")
    private String name; // 审查内容及标准
    @TableField(value="code")
    private String code; // 编码
    @TableField(value="parent_id")
    private Long parentId; // 父ID
    @TableField(value="tid")
    private String tid;
    @TableField(value="tpid")
    private String tpid;
    @TableField(value="detail_index")
    private String detailIndex;

    public String getDetailIndex() {
        return detailIndex;
    }

    public void setDetailIndex(String detailIndex) {
        this.detailIndex = detailIndex;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
    public Integer getSequence() {
        return sequence;
    }

    public void setSequence(Integer sequence) {
        this.sequence = sequence;
    }
    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }
    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }
    public Long getParentId() {
        return parentId;
    }

    public void setParentId(Long parentId) {
        this.parentId = parentId;
    }
    
}
